@@ -16,20 +16,20 @@ field_specs = {
 }
 
 
-def update_location(thng_id, position=None, timestamp=None, api_key=None):
+def update_location(thng, position=None, timestamp=None, api_key=None):
     data = {'position': position, 'timestamp': timestamp}
     assertions.validate_field_specs(data, field_specs)
-    url = '/thngs/{}/location'.format(thng_id)
+    url = '/thngs/{}/location'.format(thng)
     return utils.request('PUT', url, data=data, api_key=api_key)
 
 
-def list_locations(thng_id, api_key=None, **request_kwargs):
-    assertions.datatype_str('thng_id', thng_id)
-    url = '/thngs/{}/location'.format(thng_id)
+def list_locations(thng, api_key=None, **request_kwargs):
+    assertions.datatype_str('thng', thng)
+    url = '/thngs/{}/location'.format(thng)
     return utils.request('GET', url, api_key=api_key, **request_kwargs)
 
 
-def delete_location(thng_id, api_key=None):
-    assertions.datatype_str('thng_id', thng_id)
-    url = '/thngs/{}/location'.format(thng_id)
+def delete_location(thng, api_key=None):
+    assertions.datatype_str('thng', thng)
+    url = '/thngs/{}/location'.format(thng)
     return utils.request('DELETE', url, api_key=api_key)
